@@ -18,7 +18,8 @@ from django.utils.translation import ugettext_lazy as _
 from tastypie import fields, bundle, http
 from tastypie.authentication import Authentication,ApiKeyAuthentication
 from tastypie.authorization import Authorization
-from tastypie.exceptions import NotFound, BadRequest, InvalidFilterError, HydrationError, InvalidSortError, ImmediateHttpResponse
+from tastypie.exceptions import NotFound, BadRequest, InvalidFilterError 
+from tastypie.exceptions import Unauthorized, HydrationError, InvalidSortError, ImmediateHttpResponse
 from tastypie.models import ApiKey
 from tastypie.resources import ModelResource, convert_post_to_patch, dict_strip_unicode_keys
 from tastypie.utils import trailing_slash
@@ -58,42 +59,45 @@ class UserResource(ModelResource):
     class Meta:
         queryset = User.objects.all()
         resource_name = 'user'
-        fields = ['first_name', 'last_name', 'last_login','username','points','badges']
+        fields = ['first_name', 'last_name', 'last_login','username', 'points','badges']
         allowed_methods = ['post']
         authentication = Authentication()
-        authorization = Authorization() 
+        authorization = Authorization()
         serializer = UserJSONSerializer()
         always_return_data = True       
     
     def obj_create(self, bundle, **kwargs):
+        
+        if 'username' not in bundle.data:
+            raise BadRequest(_(u'Username missing'))
+        
+        if 'password' not in bundle.data:
+            raise BadRequest(_(u'Password missing'))
+        
         username = bundle.data['username']
         password = bundle.data['password']
-        if not username or not password:
-            raise BadRequest(_(u'Username or password missing'))
         
         u = authenticate(username=username, password=password)
         if u is not None:
             if u.is_active:
                 login(bundle.request,u)
             else:
-                # TODO - should raise 401 error
                 raise BadRequest(_(u'Authentication failure'))
         else:
-            # TODO should raise 401 error
             raise BadRequest(_(u'Authentication failure'))
 
         del bundle.data['password']
         key = ApiKey.objects.get(user = u)
         bundle.data['api_key'] = key.key
-        bundle.obj = u
+        bundle.obj = u 
         return bundle 
     
     def dehydrate_points(self,bundle):
-        points = Points.get_userscore(User.objects.get(username__exact=bundle.data['username']))
+        points = Points.get_userscore(User.objects.get(username=bundle.request.user.username))
         return points
     
     def dehydrate_badges(self,bundle):
-        badges = Award.get_userawards(User.objects.get(username__exact=bundle.data['username']))
+        badges = Award.get_userawards(User.objects.get(username=bundle.request.user.username))
         return badges 
 
 class RegisterResource(ModelResource):
@@ -113,7 +117,13 @@ class RegisterResource(ModelResource):
         include_resource_uri = False
          
     def obj_create(self, bundle, **kwargs):
-        data = { 'username': bundle.data['username'],
+        required = ['username','password','passwordagain', 'email', 'firstname', 'lastname']
+        for r in required:
+            try:
+                bundle.data[r]
+            except KeyError:
+                raise BadRequest(_(u'Please enter your %s') % r)
+        data = {'username': bundle.data['username'],
                 'password': bundle.data['password'],
                 'password_again': bundle.data['passwordagain'],
                 'email': bundle.data['email'],
@@ -144,7 +154,6 @@ class RegisterResource(ModelResource):
             key = ApiKey.objects.get(user = u)
             bundle.data['api_key'] = key.key
         except IntegrityError:
-            # TODO translation
             raise BadRequest(_(u'Username "%s" already in use, please select another' % username))
         del bundle.data['passwordagain']
         del bundle.data['password']
@@ -171,30 +180,14 @@ class TrackerResource(ModelResource):
     class Meta:
         queryset = Tracker.objects.all()
         resource_name = 'tracker'
-        allowed_methods = ['post','patch','put']
-        detail_allowed_methods = ['post','patch','put']
+        allowed_methods = ['post','patch']
+        detail_allowed_methods = ['post','patch']
         authentication = ApiKeyAuthentication()
         authorization = Authorization() 
         serializer = PrettyJSONSerializer()
         always_return_data =  True
         fields = ['points','digest','data','tracker_date','badges','course','completed']
-        
-    def is_valid(self, bundle, request=None):
-        exists = False
-        try:
-            activity = Activity.objects.get(digest=bundle.obj.digest)
-            exists = True
-        except Activity.DoesNotExist:
-            pass
-        
-        try:
-            media = Media.objects.get(digest=bundle.obj.digest)
-            exists = True
-        except Media.DoesNotExist:
-            pass
-        if not exists:
-            raise NotFound
-            
+              
     def hydrate(self, bundle, request=None):
         # remove any id if this is submitted - otherwise it may overwrite existing tracker item
         if 'id' in bundle.data:
@@ -224,7 +217,7 @@ class TrackerResource(ModelResource):
             if json_data['activity'] == "completed":
                 bundle.obj.completed = True
         except:
-            pass
+            bundle.obj.completed = False
         
         try:
             json_data = json.loads(bundle.data['data'])
@@ -280,8 +273,11 @@ class CourseResource(ModelResource):
         self.throttle_check(request)
         
         pk = kwargs.pop('pk', None)
-        course = self._meta.queryset.get(pk = pk)
-        
+        try:
+            course = self._meta.queryset.get(pk = pk)
+        except Course.DoesNotExist:
+            raise NotFound(_(u'Course download not found'))
+         
         file_to_download = course.getAbsPath();
         schedule = course.get_default_schedule()
         has_completed_trackers = Tracker.has_completed_trackers(course,request.user)
